# WQt - A Qt project manager

WQt is a Qt project management tool which allows the user to create, update, build, and run Qt projects. It used CMake to build the project, hence making it compatible with almost any text editor and IDE.